@@ -672,7 +672,7 @@ class AudioPlayer(OpenLPMixin, QtCore.QObject):
         """
         Skip forward to the next track in the list
         """
-        self.player.next()
+        self.playlist.next()
 
     def go_to(self, index):
         """
