@@ -4,7 +4,7 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2016 OpenLP Developers                                   #
+# Copyright (c) 2008-2017 OpenLP Developers                                   #
 # --------------------------------------------------------------------------- #
 # This program is free software; you can redistribute it and/or modify it     #
 # under the terms of the GNU General Public License as published by the Free  #
@@ -61,9 +61,8 @@ def source_group(inputs, source_text):
     """
     groupdict = {}
     keydict = {}
-    checklist = inputs
-    key = checklist[0][0]
-    for item in checklist:
+    key = inputs[0][0]
+    for item in inputs:
         if item[0] == key:
             groupdict[item] = source_text[item]
             continue
@@ -75,7 +74,7 @@ def source_group(inputs, source_text):
     return keydict
 
 
-def Build_Tab(group, source_key, default, projector, projectordb, edit=False):
+def build_tab(group, source_key, default, projector, projectordb, edit=False):
     """
     Create the radio button page for a tab.
     Dictionary will be a 1-key entry where key=tab to setup, val=list of inputs.
@@ -174,7 +173,7 @@ class FingerTabBarWidget(QtWidgets.QTabBar):
         :param width: Remove default width parameter in kwargs
         :param height: Remove default height parameter in kwargs
         """
-        self.tabSize = QtWidgets.QSize(kwargs.pop('width', 100), kwargs.pop('height', 25))
+        self.tabSize = QtCore.QSize(kwargs.pop('width', 100), kwargs.pop('height', 25))
         QtWidgets.QTabBar.__init__(self, parent, *args, **kwargs)
 
     def paintEvent(self, event):
@@ -275,7 +274,7 @@ class SourceSelectTabs(QtWidgets.QDialog):
         keys.sort()
         if self.edit:
             for key in keys:
-                (tab, button_count, buttonchecked) = Build_Tab(group=self.button_group,
+                (tab, button_count, buttonchecked) = build_tab(group=self.button_group,
                                                                source_key={key: self.source_group[key]},
                                                                default=self.projector.source,
                                                                projector=self.projector,
@@ -290,7 +289,7 @@ class SourceSelectTabs(QtWidgets.QDialog):
                                                          QtWidgets.QDialogButtonBox.Cancel)
         else:
             for key in keys:
-                (tab, button_count, buttonchecked) = Build_Tab(group=self.button_group,
+                (tab, button_count, buttonchecked) = build_tab(group=self.button_group,
                                                                source_key={key: self.source_group[key]},
                                                                default=self.projector.source,
                                                                projector=self.projector,
