@@ -23,10 +23,10 @@
 This module contains tests for the OpenLP song importer.
 """
 from unittest import TestCase
+from unittest.mock import patch, MagicMock
 
-from openlp.plugins.songs.lib.importers.openlp import OpenLPSongImport
 from openlp.core.common import Registry
-from tests.functional import patch, MagicMock
+from openlp.plugins.songs.lib.importers.openlp import OpenLPSongImport
 
 
 class TestOpenLPImport(TestCase):
